@@ -19,7 +19,7 @@ class Scenario:
 
   def _encode_json(j):
     return json.dumps(j).encode()
-  
+
   def _decode_json(b):
     return json.loads(b.decode())
 
@@ -33,11 +33,11 @@ class Scenario:
       raise ScenarioNotStartedException
     self.token = res["stoken"]
     self.init = True
- 
+
   def _continue_scenario(self, j):
     j |= {"stoken": self.token, "scontinue": True}
     self.cli._send(Scenario._encode_json(j))
-    
+
   def _terminate_scenario(self, j):
     j |= {"stoken": self.token, "sfinish": True}
     self.token = None
@@ -71,7 +71,7 @@ class Scenario:
   def store_cells(self, values_dict):
     j = {"store_in_memory": values_dict}
     self._decide(j)
-    
+
   def read_cells(self, keys_arr, buffer_size=8192):
     if not self.init or self.nis:
       return None
@@ -85,7 +85,7 @@ class Scenario:
   def listen(self):
     if not self.init or self.nis:
       raise ScenarioNotStartedException
-    j = Scenario._decode_json(self._waits_for())
+    j = Scenario._decode_json(self.srv._waits_for())
     if "sfinish" in j:
       if j["sfinish"] is True:
         raise ScenarioTerminatedException
@@ -93,3 +93,12 @@ class Scenario:
 
   def next_is_last(self):
     self.nis = True
+
+  def wait(self):
+    while True:
+      msg = scn.listen()
+      if len(msg) == 0:
+        continue
+      if msg['author'] == 1:
+        continue
+      return msg
